/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
/**
 * Defines the structure for a Calendar date selection range.
 *
 * This interface represents a date range with a start and end date,
 * commonly used in range selection scenarios.
 *
 * @example
 * ```typescript
 * const range: SelectionRange = {
 *   start: new Date(2023, 0, 1),
 *   end: new Date(2023, 0, 31)
 * };
 * ```
 */
export interface SelectionRange {
    /**
     * The starting date of the selection range.
     * Can be null when no start date has been selected.
     */
    start: Date | null;
    /**
     * The ending date of the selection range.
     * Can be null when no end date has been selected or only start date is set.
     */
    end: Date | null;
}
/**
 * A constant representing an empty selection range with both start and end set to null.
 *
 * @hidden
 */
export declare const EMPTY_SELECTIONRANGE: SelectionRange;
