/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { TemplateRef } from '@angular/core';
import * as i0 from "@angular/core";
/**
 * A directive for customizing the cells in the Calendar component.
 *
 * This directive allows you to define a custom template for rendering the content of calendar cells
 * in the month view. The template context provides access to the current date and cell context information.
 *
 * Template Context Variables:
 * - `date` - The Date object representing the current cell's date
 * - `cellContext` - Additional context information about the current cell
 *
 * For more examples, refer to the article on [templates]({% slug templates_calendar %}).
 *
 * `kendoCalendarCellTemplate` is equivalent to
 * [`kendoCalendarMonthCellTemplate`]({% slug api_dateinputs_monthcelltemplatedirective %}).
 *
 * @example
 * ```html
 * <kendo-calendar>
 *   <ng-template kendoCalendarCellTemplate let-date let-cellContext="cellContext">
 *     <span class="custom">{{date.getDate()}}</span>
 *   </ng-template>
 * </kendo-calendar>
 * ```
 */
export declare class CellTemplateDirective {
    templateRef: TemplateRef<any>;
    constructor(templateRef: TemplateRef<any>);
    static ɵfac: i0.ɵɵFactoryDeclaration<CellTemplateDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<CellTemplateDirective, "[kendoCalendarCellTemplate]", never, {}, {}, never, never, true, never>;
}
