/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { TemplateRef } from '@angular/core';
import * as i0 from "@angular/core";
/**
 * A directive for customizing the decade cells in the Calendar component.
 *
 * This directive allows you to define a custom template for rendering the content of decade cells
 * when the Calendar is in decade view. The template context provides access to the current date
 * and cell context information.
 *
 * Template Context Variables:
 * - `date` - The Date object representing the current cell's date
 * - `cellContext` - Additional context information about the current decade cell
 *
 * For more examples, refer to the article on [templates]({% slug templates_calendar %}).
 *
 * @example
 * ```html
 * <kendo-calendar [activeView]="activeView">
 *   <ng-template kendoCalendarDecadeCellTemplate let-context="cellContext">
 *     <span class="custom">{{context.formattedValue}}</span>
 *   </ng-template>
 * </kendo-calendar>
 * ```
 */
export declare class DecadeCellTemplateDirective {
    templateRef: TemplateRef<any>;
    constructor(templateRef: TemplateRef<any>);
    static ɵfac: i0.ɵɵFactoryDeclaration<DecadeCellTemplateDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<DecadeCellTemplateDirective, "[kendoCalendarDecadeCellTemplate]", never, {}, {}, never, never, true, never>;
}
