/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { TemplateRef } from '@angular/core';
import * as i0 from "@angular/core";
/**
 * A directive for customizing the footer in the Calendar component.
 *
 * This directive allows you to define a custom template for rendering the footer content.
 * The template context provides access to the current date and active view.
 *
 * Template Context Variables:
 * - `date` - The Date object representing the current calendar context
 * - `activeView` - The current active view of the Calendar
 *
 * For more examples, refer to the article on [templates]({% slug templates_calendar %}).
 *
 * @example
 * ```html
 * <kendo-calendar>
 *   <ng-template kendoCalendarFooterTemplate let-date let-activeView="activeView">
 *     <div class="custom">
 *       Today: {{date | date:'short'}} ({{activeView}} view)
 *     </div>
 *   </ng-template>
 * </kendo-calendar>
 * ```
 */
export declare class FooterTemplateDirective {
    templateRef: TemplateRef<any>;
    constructor(templateRef: TemplateRef<any>);
    static ɵfac: i0.ɵɵFactoryDeclaration<FooterTemplateDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<FooterTemplateDirective, "[kendoCalendarFooterTemplate]", never, {}, {}, never, never, true, never>;
}
