/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { TemplateRef } from '@angular/core';
import * as i0 from "@angular/core";
/**
 * A directive for customizing the entire header in the Calendar component.
 *
 * This directive allows you to define a custom template for rendering the complete header content,
 * including navigation controls and title. The template context provides access to the title text,
 * current date, and active view.
 *
 * Template Context Variables:
 * - `title` - The formatted title text for the header
 * - `date` - The Date object representing the current header context
 * - `activeView` - The current active view of the Calendar
 *
 * For more examples, refer to the article on [templates]({% slug templates_calendar %}).
 *
 * @example
 * ```html
 * <kendo-calendar>
 *   <ng-template kendoCalendarHeaderTemplate let-title let-date="date">
 *     <div class="custom">
 *       <span>{{title}}</span>
 *       <small>{{date | date:'yyyy-MM-dd'}}</small>
 *     </div>
 *   </ng-template>
 * </kendo-calendar>
 * ```
 */
export declare class HeaderTemplateDirective {
    templateRef: TemplateRef<any>;
    constructor(templateRef: TemplateRef<any>);
    static ɵfac: i0.ɵɵFactoryDeclaration<HeaderTemplateDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<HeaderTemplateDirective, "[kendoCalendarHeaderTemplate]", never, {}, {}, never, never, true, never>;
}
