/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { TemplateRef } from '@angular/core';
import * as i0 from "@angular/core";
/**
 * A directive for customizing the navigation items in the Calendar component.
 *
 * This directive allows you to define a custom template for rendering the content of navigation items
 * in the Calendar header. The template context provides access to the title, current date, and active view.
 *
 * Template Context Variables:
 * - `title` - The formatted title text for the navigation item
 * - `date` - The Date object representing the current navigation context
 * - `activeView` - The current active view of the Calendar
 *
 * For more examples, refer to the article on [templates]({% slug templates_calendar %}).
 *
 * @example
 * ```html
 * <kendo-calendar>
 *   <ng-template kendoCalendarNavigationItemTemplate let-title let-date="date">
 *     <span class="custom">{{title}} - {{date | date:'yyyy'}}</span>
 *   </ng-template>
 * </kendo-calendar>
 * ```
 */
export declare class NavigationItemTemplateDirective {
    templateRef: TemplateRef<any>;
    constructor(templateRef: TemplateRef<any>);
    static ɵfac: i0.ɵɵFactoryDeclaration<NavigationItemTemplateDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<NavigationItemTemplateDirective, "[kendoCalendarNavigationItemTemplate]", never, {}, {}, never, never, true, never>;
}
