/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { TemplateRef } from '@angular/core';
import * as i0 from "@angular/core";
/**
 * A directive for customizing the week number cells in the Calendar component.
 *
 * This directive allows you to define a custom template for rendering the content of week number cells
 * in the month view when the weekNumber property is enabled. The template context provides access to
 * the current date and cell context information.
 *
 * Template Context Variables:
 * - `date` - The Date object representing the current week's date
 * - `cellContext` - Additional context information about the current week number cell
 *
 * For more examples, refer to the article on [templates]({% slug templates_calendar %}).
 *
 * @example
 * ```html
 * <kendo-calendar [weekNumber]="true">
 *   <ng-template kendoCalendarWeekNumberCellTemplate let-context="cellContext">
 *     <span class="custom">W{{context.formattedValue}}</span>
 *   </ng-template>
 * </kendo-calendar>
 * ```
 */
export declare class WeekNumberCellTemplateDirective {
    templateRef: TemplateRef<any>;
    constructor(templateRef: TemplateRef<any>);
    static ɵfac: i0.ɵɵFactoryDeclaration<WeekNumberCellTemplateDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<WeekNumberCellTemplateDirective, "[kendoCalendarWeekNumberCellTemplate]", never, {}, {}, never, never, true, never>;
}
