/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { DateFormatOptions } from "@progress/kendo-intl";
/**
 * Represents the Kendo UI DateInput format settings interface.
 * Specifies the formats used by the `DateInput` mask when the input is focused or blurred ([see example]({% slug formats_datepicker %}#toc-display-and-input-formats)).
 *
 * @example
 * ```html
 * <kendo-dateinput
 *   [formatSettings]="{
 *     inputFormat: 'MM/dd/yyyy',
 *     displayFormat: 'MMMM dd, yyyy'
 *   }">
 * </kendo-dateinput>
 * ```
 */
export interface FormatSettings {
    /**
     * Specifies the format used when the input is focused.
     */
    inputFormat: string | DateFormatOptions;
    /**
     * Specifies the format used when the input is blurred.
     */
    displayFormat: string | DateFormatOptions;
}
